Documentation
¶
Overview ¶
libXray is an Xray wrapper focusing on improving the experience of Xray-core mobile development.
Index ¶
- func ConvertShareLinksToXrayJson(base64Text string) string
- func ConvertXrayJsonToShareLinks(base64Text string) string
- func CountGeoData(base64Text string) string
- func GetFreePorts(count int) string
- func GetXrayState() bool
- func InitDns(base64Text string) string
- func NewInitDnsRequest(dns, deviceName string) (string, error)
- func NewXrayRunFromJSONRequest(datDir, configJSON string) (string, error)
- func NewXrayRunRequest(datDir, configPath string) (string, error)
- func Ping(base64Text string) string
- func QueryStats(base64Text string) string
- func ReadGeoFiles(base64Text string) string
- func ResetDns() string
- func RunXray(base64Text string) string
- func RunXrayFromJSON(base64Text string) string
- func StopXray() string
- func TestXray(base64Text string) string
- func XrayVersion() string
- type CountGeoDataRequest
- type InitDnsRequest
- type RunXrayFromJSONRequest
- type RunXrayRequest
- type TestXrayRequest
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertShareLinksToXrayJson ¶
Convert share text to XrayJson support XrayJson, v2rayN plain text, v2rayN base64 text, Clash.Meta yaml
func ConvertXrayJsonToShareLinks ¶
Convert XrayJson to share links. VMess will generate VMessAEAD link.
func CountGeoData ¶
Read geo data and write all codes to text file.
func GetFreePorts ¶
Wrapper of nodep.GetFreePorts count means how many ports you need.
func NewInitDnsRequest ¶
Init Dns Request
func NewXrayRunFromJSONRequest ¶
Create Xray Run From JSON Request
func NewXrayRunRequest ¶
Create Xray Run Request
func RunXrayFromJSON ¶
Run Xray instance with JSON configuration.
Types ¶
type CountGeoDataRequest ¶
type InitDnsRequest ¶
type RunXrayFromJSONRequest ¶
type RunXrayRequest ¶
type TestXrayRequest ¶
Click to show internal directories.
Click to hide internal directories.