geo

package
v1.90.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CountGeoData

func CountGeoData(datDir string, name string, geoType string) error

Read geo data and write all codes to text file. datDir means the dir which geo dat are in. name means the geo dat file name, like "geosite", "geoip" geoType must be the value of geoType

func ReadGeoFiles

func ReadGeoFiles(xrayBytes []byte) ([]string, []string)

Read all geo files in config file. configPath means where xray config file is.

Types

This section is empty.

Jump to