Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CountGeoData ¶
Read geo data and write all codes to text file. datDir means the dir which geo dat are in. name means the geo dat file name, like "geosite", "geoip" geoType must be the value of geoType
func ReadGeoFiles ¶
Read all geo files in config file. configPath means where xray config file is.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.